@@ -19,13 +19,13 @@ use Version::Compare;
 use Path::Class;
 use ExtUtils::Installed;
 
-our $VERSION = '0.06.1';
+our $VERSION = '0.066_001';
 
 =head1 NAME
 
-Dependencies::Searcher - Search recursively dependencies used in a
-module's directory and build a report that can be used as a L<Carton|Carton>
-cpanfile.
+Dependencies::Searcher - Search for modules used or required by a
+distribution and build a report that can be used as L<Carton|Carton>
+cpanfile .
 
 =cut
 
@@ -42,13 +42,30 @@ cpanfile.
 
     $searcher->generate_report($searcher->non_core_modules);
 
-    # Prints
-    # requires Data::Printer, 0.35
-    # requires Moose, 2.0602
-    # requires IPC::Cmd
-    # requires Module::Version
+    # Prints to cpanfile
+    # requires 'Data::Printer', '0.35';
+    # requires Moose, '2.0602';
+    # requires IPC::Cmd;
+    # requires Module::Version;
     # ...
 
+    Synopsis from Dependencies::Searcher::AckRequester
+
+    # Places to search...
+    my @path = ("./lib", "./Makefile.PL", "./script");
+
+    # Params for Ack
+    my @params = ('--perl', '-hi', $pattern, @path);
+
+    # Absolute path to the Ack binary
+    my $ack_path = $requester->get_path();
+
+    # Build the command for IPC::Cmd
+    my $cmd_use = $requester->build_cmd(@params);
+
+    # Execute the command and retrieve the output
+    my @moduls = $requester->ack($cmd_use);
+
 =cut
 
 =head1 DESCRIPTION
@@ -119,8 +136,13 @@ has 'core_modules' => (
     },
 );
 
+has 'full_path' => (
+  is  => 'rw',
+  isa => 'Str',
+);
+
 # Log stuff here
-local $ENV{LM_DEBUG} = 0; # 1 for debug logs, 0 for info
+$ENV{LM_DEBUG} = 1; # 1 for debug logs, 0 for info
 
 my $work_path = File::HomeDir->my_data;
 my $log_fh = File::Stamped->new(
@@ -135,10 +157,6 @@ $Log::Minimal::PRINT = sub {
     print {$log_fh} "$time [$type] $message\n";
 };
 
-infof('  * * * * * * * * * * * * * * * * * * * *');
-infof('* H E R E   I S   A   N E W   S E A R C H *');
-infof('  * * * * * * * * * * * * * * * * * * * *');
-
 infof("Dependencies::Searcher $VERSION debugger init.");
 infof("Log file available in " . $work_path);
 # End of log init
@@ -274,12 +292,24 @@ sub clean_everything {
 	# Remove any qw(xxxxx xxxxx) or qw[xxx xxxxx]
 	# '\(' are for real 'qw()' parenthesis not for grouping
 	# Also removes empty qw()
-	$module =~ s{
+
+        # With spaces and parenthesis e.g. qw( foo bar )
+        $module =~ s{
 			\s qw
 			\(
-			([A-Za-z]+(\s*[A-Za-z]*))*
+			(\s*[A-Za-z]+(\s*[A-Za-z]*))*\s*
 			\)
 		}{}xi;
+
+        # Without spaces, with  parenthesis e.g. qw(foo bar) and optionnal [method_names
+        $module =~ s{
+			\s qw
+			\(
+			([A-Za-z]+(_[A-Za-z]+)*(\s*[A-Za-z]*))*
+			\)
+		}{}xi;
+
+        # With square brackets e.g. qw[foo bar] and optionnal [method_names]
 	$module =~ s{
 			\s qw
 			\[
@@ -287,6 +317,14 @@ sub clean_everything {
 			\]
 		}
 		    {}xi; # Empty subtitution
+        # With spaces and parenthesis e.g. qw/ foo bar /
+	$module =~ s{
+			\s qw
+			\/
+			(\s[A-Za-z]+(_[A-Za-z]+)*(\s*[A-Za-z]*))*\s
+			\/
+		}
+		    {}xi; # Empty subtitution
 
 	# Remove method names between quotes (those that can be used
 	# without class instantiation)
@@ -459,12 +497,12 @@ sub generate_report {
 	    chomp($module_name, $version);
 
 	    if ($version =~ m/[0-9]\.[0-9]+/ ) {
-		say $cpanfile_fh "requires " . $module_name . ", " . $version;
+		say $cpanfile_fh "requires '$module_name', '$version';";
 	    } # else : other case ?
 
 	} else {
 	    debugf("Module + version : " . $module_name);
-	    say $cpanfile_fh "requires " . $module_name;
+	    say $cpanfile_fh "requires '$module_name';";
 	}
 
     }
@@ -473,6 +511,62 @@ sub generate_report {
     infof("File has been generated and is waiting for you");
 }
 
+# From Dependencies::Searcher::AckRequester, DEPRECATED
+sub get_path {
+    my $self = shift;
+
+    my $tmp_full_path = can_run('ack');
+
+    if ($tmp_full_path) {
+	$self->full_path($tmp_full_path);
+	debugf("Ack full path : " . $self->full_path);
+	return $self->full_path;
+    } else {
+	critf('Something goes wrong with Ack path or IPC::Run is not available !');
+    }
+}
+
+
+sub build_cmd {
+
+    my ($self, @params) = @_;
+
+    my @cmd = ($self->full_path, @params);
+    my $cmd_href = \@cmd;
+
+    return $cmd_href;
+}
+
+# From Dependencies::Searcher::AckRequester, DEPRECATED
+# Maybe this is not very clean, but it works
+sub ack {
+    my ($self, $cmd) = @_;
+
+    my (
+	$success,
+	$error_message,
+	$full_buffer,
+	$stdout_buffer,
+	$stderr_buffer
+    ) = run (
+	command => $cmd,
+	verbose => 0
+    );
+
+    my @modules;
+
+    debugf("All modules in distribution : " . join "", @$full_buffer);
+
+    if ($success) {
+	push @modules, split(/\n/m, $$full_buffer[0]);
+    } else {
+	say "No module have been found or IPC::Cmd failed with error $error_message";
+    }
+
+    return @modules;
+}
+
+
 1;
 
 __END__
@@ -590,6 +684,46 @@ Generate a hash containing the modules could be achieved. Someday.
 
 =cut
 
+=head2 get_path()
+
+Returns the L<ack> full path if installed. Set the C<full_path>
+L<Moose> attribute that will be used by ICP::Cmd. It verify also that
+L<Ack> is reachable or warns about it.
+
+=cut
+
+=head2 build_cmd(@params)
+
+C<build_cmd()> takes as parameter all the arguments Ack will
+need. L<Dependencies::Searcher> defines it like this :
+
+=over 4
+
+=item * C<--perl>   : tells to search in Perl like files (C<*.pm>, C<*.pl>, etc.) 
+
+=item * C<-hi>      : suppress the prefixing filename on output + ignore
+case
+
+=item * C<$pattern> : must be passed from your implementation
+
+=item * C<@path>    : files and directories where L<ack> will go 
+
+All these params are merged in an only array reference that is returned for
+later use with L<IPC::Cmd>.
+
+=back
+
+=cut
+
+=head2 ack($params_array_ref)
+
+Execute the L<IPC::Cmd> command that calls C<ack> and returns an array of
+potentially interesting lines, containing dependencies names but some
+crap inside too.
+
+=cut
+
+
 =head2 Log::Minimal::PRINT override
 
 Just override the way Log::Minimal is used. See LOGGING AND DEBUGGING
@@ -633,6 +767,15 @@ things, even if Ack do the stuff proudly this way.
 Thanks to cpantesters.org community reports, things should go better and
 better.
 
+=head2 Fun : some are able to do it using a one-liner
+
+Command Line Magic (@climagic) tweeted 4:17 PM on lun., nov. 25, 2013
+
+    # Not perfect, but gives you a start on the Perl modules in use.
+    grep -rh ^use --include="*.pl" --include="*.pm" . | sort | uniq -c
+
+See original Tweet https://twitter.com/climagic/status/404992356513902592
+
 =cut
 
 =head1 BUGS
@@ -689,6 +832,8 @@ smonff, C<< <smonff at gmail.com> >>
 
 =item * Nikolay Mishin (mishin) helps to make it more cross-platform
 
+=item * Alexandr Ciornii (chorny) advises on version numbers
+
 =back
 
 =cut
@@ -697,27 +842,28 @@ smonff, C<< <smonff at gmail.com> >>
 
 =over
 
-=item * Brian D. Foy's L<Module::Extract::Use|Module::Extract::Use>
+=item L<Module::Extract::Use|Module::Extract::Use>
 
 Was the main inspiration for this one. First, I want to use it for my needs
 but it was not recursive...
 
 See L<https://metacpan.org/module/Module::Extract::Use>
 
-=item * L<Module::CoreList|Module::CoreList>
+=item L<Module::CoreList|Module::CoreList>
 
 What modules shipped with versions of perl. I use it extensively to detect
 if the module is from Perl Core or not.
 
 See L<http://perldoc.perl.org/Module/CoreList.html>
 
-=item * Andy Lester's Ack
+=item L<http://beyondgrep.com/|Ack>
 
-I've use it as the main source for the module. It was pure Perl so I've choose
-it, even if Ack is not meant for being used programatically, this use do the
-job.
-
-See L<http://beyondgrep.com/>
+Ack gives me the wish to try to write this module. It was pure Perl so
+I've choose it because it was possible to install it through CPAN
+during the distribution installation process. Even if Ack was not
+meant for being used programatically, this hacked use of Ack did the
+job during the first part of this module's life. These dready parts
+(use of Ack with IPC::Cmd) have been removed since.
 
 =back
 
@@ -729,6 +875,8 @@ See also :
 
 =item * http://stackoverflow.com/questions/17771725/
 
+=item * https://metacpan.org/module/Dist::Zilla::Plugin::AutoPrereqs
+
 =back
 
 =head1 LICENSE AND COPYRIGHT
